ELPDweight: Return the probability of models compared with loo being the best for prediction
Description
Calculate the probability of models compared with loo being the best for prediction.
It uses simulation using the pointwise LOO log-predictive densities. This preserves the correlation
between models, because all models are evaluated on the same observations. This is the approach
recommended by Aki Vehtari et al. (2017) when uncertainty in model comparison matters.
Usage
ELPDweight(
loos = stop("A named list of loo data must be provided."),
nreplicates = 10000
)
ELPDweight calculates the probability that each model is best for prediction
References
Vehtari, A., Gelman, A., & Gabry, J. (2017). Practical Bayesian model evaluation using leave-one-out cross-validation and WAIC. Statistics and Computing, 27(5), 1413-1432. https://doi.org/10.1007/s11222-016-9696-4
See Also
Other AIC:
ExtractAIC.glm(),
FormatCompareAIC(),
compare_AIC(),
compare_AICc(),
compare_BIC()